@@ -1,5 +1,5 @@
 package Syntax::Feature::ValuesOnArray; # so as not to confuse dzil?
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 use strict;
 use warnings;
 use Syntax::Feature::EachOnArray ();
@@ -31,7 +31,7 @@ sub install {
 
     return unless $^V lt 5.12.0;
     no strict 'refs';
-    *{"$args{into}::values"} = \&avalues;
+    *{"$args{into}::values"} = \&Tie::ArrayAsHash::avalues;
 }
 
 # XXX on uninstall, delete symbol
@@ -49,7 +49,7 @@ Syntax::Feature::ValuesOnArray - Emulate values(@array) on Perl < 5.12
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -64,6 +64,8 @@ version 0.03
 Beginning with 5.12, Perl supports values() on array. This syntax extension
 emulates the support on older Perls.
 
+=for Pod::Coverage ^(install)$
+
 =head1 CAVEATS
 
 No uninstall() yet.
@@ -82,7 +84,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
